﻿using System;
using Wisej.Web;
using Wisej.Web.Ext.GoogleMaps;

namespace TestAddress
{
    public partial class TestPage : Page
    {
        public string Latitude { get; private set; }
        public string Longitude { get; private set; }
        public string Distance { get; private set; }
        public string Message { get; private set; }
        public string Address { get; private set; }

        public GeocoderResult[] Geocodes { get; private set; }

        public TestPage()
        {
            InitializeComponent();
        }

        private void TestPage_Load(object sender, EventArgs e)
        {
            StaffLocation.ActiveWatch = true;
            StaffLocation.EnableHighAccuracy = true;
            Longitude = Latitude = "";
            StaffLocation.PositionChanged += StaffLocation_PositionChanged;
        }

        private void buttonGetCoords_Click(object sender, EventArgs e)
        {
            if (Longitude != "")
            {
                buttonGetCoords.Enabled = false;
                StaffLocation.PositionChanged -= StaffLocation_PositionChanged;
                HandleCoords();
            }
        }

        private void HandleCoords()
        {
            textBoxCoords.Text = $"Lat {Latitude} - Lng {Longitude}";

            googleMap.Visible = false;

            googleMap.GetGeocode(ReceiveGeocoderResult, double.Parse(Latitude), double.Parse(Longitude));
        }

        private void ReceiveGeocoderResult(GeocoderResult[] geocode)
        {
            Geocodes = geocode;
            if (Geocodes[0].IsError)
            {
                MessageBox.Show($"Received error {Geocodes[0].ResultCode}",
                    "Search Error",
                    MessageBoxButtons.OK,
                    MessageBoxIcon.Error);
                Geocodes = null;
            }
            else
            {
                textBoxAddress.Text = Geocodes[0].FormattedAddress;
            }
        }

        private async void buttonGetAddress_Click(object sender, EventArgs e)
        {
            Geocodes = await googleMap.GetGeocodeAsync(double.Parse(Latitude), double.Parse(Longitude));

            if (Geocodes[0].IsError)
            {
                MessageBox.Show($"Received error {Geocodes[0].ResultCode}",
                    "Search Error",
                    MessageBoxButtons.OK,
                    MessageBoxIcon.Error);
                Geocodes = null;
            }
            else
            {
                textBoxAddress.Text = Geocodes[0].FormattedAddress;
            }
        }

        private void StaffLocation_PositionChanged(object sender, EventArgs e)
        {
            Wisej.Ext.Geolocation.Position oPosition = StaffLocation.LastPosition;
            if (oPosition != null)
            {
                Latitude = oPosition.Latitude.ToString("0.######");
                Longitude = oPosition.Longitude.ToString("0.######");

                HandleCoords();
            }

            if (oPosition.ErrorMessage != null)
            {
                Message = oPosition.ErrorMessage;
            }
        }
    }
}